@@ -22,14 +22,14 @@
 #
 # Created:    08/07/2019
 #-------------------------------------------------------------------------------
-
-
-__version__ = '0.0.60'
+import pkg_resources
 
 def get_version():
-    return __version__
+    return pkg_resources.get_distribution(PACKAGE_NAME)
 
 
 from .sqlitedb import *
+from .postgresdb import *
 from .usersdb import *
-from .settingsdb import *
\ No newline at end of file
+from .settingsdb import *
+from .http_utils import *
